package com.vendor.loader.model.config;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.loader.Log.Log;
import com.vendor.loader.Messages;
import com.vendor.loader.model.CommonAdapter;
import com.vendor.loader.model.PartitionItem;
import com.vendor.loader.struct.UpgradeFileInfo;
import com.vendor.loader.struct.UpgradeInfo;
import com.vendor.loader.util.FileUtil;
import com.vendor.loader.util.IniFileParser;
import com.vendor.loader.util.InvalidDataFormatException;
import com.vendor.loader.util.PropertiesUtility;
import com.vendor.loader.util.StringUtil;
import java.io.File;
import java.io.IOException;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import org.dom4j.DocumentException;
import org.eclipse.osgi.util.NLS;

public class SOCTConfig extends PropertiesUtility {
  private static final String CONTORL_INFO_INSERTION_FREQUENCY_VALUE_MIN = "5";
  
  private static final String CONTORL_INFO_INSERTION_FREQUENCY_VALUE_MAX = "200";
  
  private String chipName;
  
  private ArrayList<UpgradeFileInfo> upgradFiles;
  
  private UpgradeInfo upgradeInfo;
  
  private boolean loadResult = false;
  
  public SOCTConfig(String configPath) {
    this.loadResult = loadSOCTConfig(configPath);
  }
  
  private boolean loadSOCTConfig(String path) {
    String configName = (new File(path)).getName();
    if (!FileUtil.isExists(path)) {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_FILE_PATH_DONT_EXIST, configName));
      return false;
    } 
    ArrayList<String> definitionLines = FileUtil.readAllLines(path);
    if (definitionLines == null) {
      Log.errorln(NLS.bind("Failed to read the file, the file path is as follows: ", path));
      return false;
    } 
    initUDProperties(definitionLines);
    if (!initParamter())
      return false; 
    if (!checkUpgrateInfo())
      return false; 
    loadUpgrateInfo();
    if (path.contains("soctota.config")) {
      if (!checkParamValue("ControlInformationInsertionFrequency", "5", "200"))
        return false; 
      this.upgradeInfo.setDataPackage(queryForInteger("ControlInformationInsertionFrequency").intValue());
    } 
    this.loadResult = true;
    Log.println(NLS.bind(Messages.MESSAGE_LOAD_FILE_SUCCESS, configName));
    return true;
  }
  
  private boolean initParamter() {
    String chipNameStr = queryForString("ChipName");
    if (isInvaildPath(chipNameStr)) {
      String upperCaseChipName = CommonAdapter.convertChipName(chipNameStr);
      setChipName(upperCaseChipName);
    } else {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "ChipName"));
      return false;
    } 
    String pathStr = queryForString("Path");
    if (isInvaildPath(pathStr)) {
      boolean result = false;
      if (pathStr.toUpperCase().endsWith("INI")) {
        result = loadIni(pathStr);
      } else if (pathStr.toUpperCase().endsWith("XML")) {
        result = loadXml(pathStr);
      } else {
        Log.errorln(NLS.bind(Messages.MESSAGE_PARTITION_LOAD_FAILED, pathStr));
        return false;
      } 
      if (!result)
        return false; 
    } else {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "Path"));
      return false;
    } 
    return true;
  }
  
  private void initUDProperties(ArrayList<String> definitionLines) {
    for (String s : definitionLines) {
      String line = s.trim().replace("\t", "");
      if (line.startsWith("["))
        continue; 
      if (line.contains("=")) {
        String[] ppt = line.split("=");
        if (ppt.length > 1)
          set(ppt[0], ppt[1]); 
      } 
    } 
  }
  
  private boolean isInvaildPath(String path) {
    if (path != null && !path.isEmpty())
      return true; 
    return false;
  }
  
  private void loadUpgrateInfo() {
    this.upgradeInfo = new UpgradeInfo();
    this.upgradeInfo.setDownloadPid(queryForInteger("PID").intValue());
    this.upgradeInfo.setDownloadTableId(queryForInteger("TableID").intValue());
    this.upgradeInfo.setManufacturerId(queryForInteger("ManufacturerID").intValue());
    this.upgradeInfo.setHardwareVersion(queryForInteger("HardwareVersion").intValue());
    this.upgradeInfo.setSoftwareVersion(queryForInteger("SoftwareVersion").intValue());
    this.upgradeInfo.setStartSn(queryForInteger("StartSequenceNumber").intValue());
    this.upgradeInfo.setEndSn(queryForInteger("EndSequenceNumber").intValue());
  }
  
  private boolean loadIni(String pathStr) {
    try {
      IniFileParser parser = new IniFileParser(pathStr);
      this.upgradFiles = parser.getUpgradFiles();
      return true;
    } catch (InvalidDataFormatException e) {
      Log.errorln(e.getMessage());
    } catch (Exception e) {
      Log.errorln(Messages.LoaderComposite_86);
    } 
    return false;
  }
  
  private boolean loadXml(String pathStr) {
    List<PartitionItem> partitionList = null;
    try {
      partitionList = PartitionItem.load(new File(pathStr), true);
      if (partitionList == null || partitionList.isEmpty()) {
        Log.errorln(NLS.bind(Messages.XMLINVALID, pathStr));
        return false;
      } 
      IniFileParser parser = new IniFileParser(partitionList);
      this.upgradFiles = parser.getUpgradFiles();
      return true;
    } catch (DocumentException e) {
      Log.errorln(NLS.bind(Messages.XMLINVALID, pathStr));
    } catch (IOException e) {
      Log.errorln(NLS.bind(Messages.XMLINVALID, pathStr));
    } catch (InvalidDataFormatException e) {
      Log.errorln(NLS.bind(Messages.XMLINVALID, pathStr));
    } 
    return false;
  }
  
  public boolean checkUpgrateInfo() {
    if (!checkParamValue("PID", "0x20", "0x1FFE"))
      return false; 
    if (!checkParamValue("TableID", "0x40", "0xFF"))
      return false; 
    if (!checkParamValue("ManufacturerID", "0x0000", "0xFFFF"))
      return false; 
    if (!checkParamValue("HardwareVersion", "0x00", "0xFFFFFFFF"))
      return false; 
    if (!checkParamValue("SoftwareVersion", "0x00000000", "0xFFFFFFFF"))
      return false; 
    if (!checkParamValue("StartSequenceNumber", "0x00000000", "0xFFFFFFFF"))
      return false; 
    if (!checkParamValue("EndSequenceNumber", "0x00000000", "0xFFFFFFFF"))
      return false; 
    try {
      BigInteger sn = StringUtil.toBigInteger(queryForString("StartSequenceNumber"));
      BigInteger en = StringUtil.toBigInteger(queryForString("EndSequenceNumber"));
      if (sn.compareTo(en) >= 0) {
        Log.showError(Messages.UpgradeInfoGroup_StartSnAndEndSnInputError);
        return false;
      } 
    } catch (NumberFormatException e) {
      Log.showError(Messages.UpgradeInfoGroup_InputInvalid);
      return false;
    } 
    return true;
  }
  
  public String getChipName() {
    return this.chipName;
  }
  
  public void setChipName(String chipName) {
    this.chipName = chipName;
  }
  
  public ArrayList<UpgradeFileInfo> getUpgradFiles() {
    return this.upgradFiles;
  }
  
  public boolean isLoadResult() {
    return this.loadResult;
  }
  
  public UpgradeInfo getUpgradeInfo() {
    return this.upgradeInfo;
  }
}
